@@ -683,7 +683,7 @@ he_color_button_clicked (GtkButton *button)
 GtkWidget *
 he_color_button_new ()
 {
-  //g_warning ("he_color_button_new");
+  g_warning ("he_color_button_new");
   return g_object_new (HE_TYPE_COLOR_BUTTON, NULL);
 }
 
@@ -739,7 +739,7 @@ void
 he_color_button_set_markup_label (HeColorButton *cb,
                            const gchar *text)
 {
-	g_warning ("he_color_button_set_color");
+	g_warning ("he_color_button_set_markup_label");
 	g_return_if_fail (HE_IS_COLOR_BUTTON (cb));
 
 	gtk_label_set_markup(GTK_LABEL (cb->priv->cLabel), text);
